# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKStatisticsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkScalarImageToTextureFeaturesFilterPython
else:
    import _itkScalarImageToTextureFeaturesFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkVectorContainerPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkArrayPython
import itk.itkContinuousIndexPython
import itk.itkIndexPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.itkRGBPixelPython

def itkScalarImageToTextureFeaturesFilterIF2_New():
    return itkScalarImageToTextureFeaturesFilterIF2.New()

class itkScalarImageToTextureFeaturesFilterIF2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToTextureFeaturesFilterIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToTextureFeaturesFilterIF2_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToTextureFeaturesFilterIF2_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageF2 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageF2"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO2 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO2"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: float
        max: float

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_SetPixelValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageF2 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageF2"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: float

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToTextureFeaturesFilterPython.delete_itkScalarImageToTextureFeaturesFilterIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToTextureFeaturesFilterIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToTextureFeaturesFilterIF2

        Create a new object of the class itkScalarImageToTextureFeaturesFilterIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToTextureFeaturesFilterIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToTextureFeaturesFilterIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToTextureFeaturesFilterIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToTextureFeaturesFilterIF2 in _itkScalarImageToTextureFeaturesFilterPython:
_itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF2_swigregister(itkScalarImageToTextureFeaturesFilterIF2)

def itkScalarImageToTextureFeaturesFilterIF3_New():
    return itkScalarImageToTextureFeaturesFilterIF3.New()

class itkScalarImageToTextureFeaturesFilterIF3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToTextureFeaturesFilterIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToTextureFeaturesFilterIF3_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToTextureFeaturesFilterIF3_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageF3 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageF3"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO3 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO3"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: float
        max: float

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_SetPixelValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageF3 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageF3"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: float

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToTextureFeaturesFilterPython.delete_itkScalarImageToTextureFeaturesFilterIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToTextureFeaturesFilterIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToTextureFeaturesFilterIF3

        Create a new object of the class itkScalarImageToTextureFeaturesFilterIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToTextureFeaturesFilterIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToTextureFeaturesFilterIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToTextureFeaturesFilterIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToTextureFeaturesFilterIF3 in _itkScalarImageToTextureFeaturesFilterPython:
_itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIF3_swigregister(itkScalarImageToTextureFeaturesFilterIF3)

def itkScalarImageToTextureFeaturesFilterISS2_New():
    return itkScalarImageToTextureFeaturesFilterISS2.New()

class itkScalarImageToTextureFeaturesFilterISS2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToTextureFeaturesFilterISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToTextureFeaturesFilterISS2_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToTextureFeaturesFilterISS2_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS2 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageSS2"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO2 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO2"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: short
        max: short

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_SetPixelValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS2 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS2"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: short

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToTextureFeaturesFilterPython.delete_itkScalarImageToTextureFeaturesFilterISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToTextureFeaturesFilterISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToTextureFeaturesFilterISS2

        Create a new object of the class itkScalarImageToTextureFeaturesFilterISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToTextureFeaturesFilterISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToTextureFeaturesFilterISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToTextureFeaturesFilterISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToTextureFeaturesFilterISS2 in _itkScalarImageToTextureFeaturesFilterPython:
_itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS2_swigregister(itkScalarImageToTextureFeaturesFilterISS2)

def itkScalarImageToTextureFeaturesFilterISS3_New():
    return itkScalarImageToTextureFeaturesFilterISS3.New()

class itkScalarImageToTextureFeaturesFilterISS3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToTextureFeaturesFilterISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToTextureFeaturesFilterISS3_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToTextureFeaturesFilterISS3_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS3 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageSS3"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO3 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO3"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: short
        max: short

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_SetPixelValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS3 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS3"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: short

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToTextureFeaturesFilterPython.delete_itkScalarImageToTextureFeaturesFilterISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToTextureFeaturesFilterISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToTextureFeaturesFilterISS3

        Create a new object of the class itkScalarImageToTextureFeaturesFilterISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToTextureFeaturesFilterISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToTextureFeaturesFilterISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToTextureFeaturesFilterISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToTextureFeaturesFilterISS3 in _itkScalarImageToTextureFeaturesFilterPython:
_itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterISS3_swigregister(itkScalarImageToTextureFeaturesFilterISS3)

def itkScalarImageToTextureFeaturesFilterIUC2_New():
    return itkScalarImageToTextureFeaturesFilterIUC2.New()

class itkScalarImageToTextureFeaturesFilterIUC2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToTextureFeaturesFilterIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToTextureFeaturesFilterIUC2_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToTextureFeaturesFilterIUC2_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC2 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageUC2"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO2 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO2"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: unsigned char
        max: unsigned char

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_SetPixelValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC2 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC2"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: unsigned char

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToTextureFeaturesFilterPython.delete_itkScalarImageToTextureFeaturesFilterIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToTextureFeaturesFilterIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToTextureFeaturesFilterIUC2

        Create a new object of the class itkScalarImageToTextureFeaturesFilterIUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToTextureFeaturesFilterIUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToTextureFeaturesFilterIUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToTextureFeaturesFilterIUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToTextureFeaturesFilterIUC2 in _itkScalarImageToTextureFeaturesFilterPython:
_itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC2_swigregister(itkScalarImageToTextureFeaturesFilterIUC2)

def itkScalarImageToTextureFeaturesFilterIUC3_New():
    return itkScalarImageToTextureFeaturesFilterIUC3.New()

class itkScalarImageToTextureFeaturesFilterIUC3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToTextureFeaturesFilterIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToTextureFeaturesFilterIUC3_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToTextureFeaturesFilterIUC3_Pointer"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC3 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageUC3"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO3 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO3"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: unsigned char
        max: unsigned char

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_SetPixelValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC3 const *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC3"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: unsigned char

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToTextureFeaturesFilterPython.delete_itkScalarImageToTextureFeaturesFilterIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToTextureFeaturesFilterIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToTextureFeaturesFilterIUC3

        Create a new object of the class itkScalarImageToTextureFeaturesFilterIUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToTextureFeaturesFilterIUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToTextureFeaturesFilterIUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToTextureFeaturesFilterIUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToTextureFeaturesFilterIUC3 in _itkScalarImageToTextureFeaturesFilterPython:
_itkScalarImageToTextureFeaturesFilterPython.itkScalarImageToTextureFeaturesFilterIUC3_swigregister(itkScalarImageToTextureFeaturesFilterIUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def scalar_image_to_texture_features_filter(*args,  requested_features: Sequence[int]=..., offsets: Sequence[Sequence[int]]=..., number_of_bins_per_axis: int=..., pixel_value_min_max: int=..., mask_image: itkt.Image=..., inside_pixel_value: int=..., fast_calculations: bool=...,**kwargs):
    """Functional interface for ScalarImageToTextureFeaturesFilter"""
    import itk

    kwarg_typehints = { 'requested_features':requested_features,'offsets':offsets,'number_of_bins_per_axis':number_of_bins_per_axis,'pixel_value_min_max':pixel_value_min_max,'mask_image':mask_image,'inside_pixel_value':inside_pixel_value,'fast_calculations':fast_calculations }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ScalarImageToTextureFeaturesFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def scalar_image_to_texture_features_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKStatistics.ScalarImageToTextureFeaturesFilter
    scalar_image_to_texture_features_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    scalar_image_to_texture_features_filter.__doc__ = filter_object.__doc__



